This is an example for distributed load testing using Neocortix Scalable Compute.
See https://neocortix.com/tutorials-loadtest-intro and https://neocortix.com/tutorials-run-loadtest for more information.
